@@ -7,12 +7,11 @@
 #
 
 
-from six.moves import xmlrpc_server as SimpleXMLRPCServer, thread
-import socket
+from six.moves import xmlrpc_server, thread
 
 
 def launch_rpc_server(bind_addr, port, project_name, run_callback):
-    server = SimpleXMLRPCServer.SimpleXMLRPCServer((bind_addr, port), logRequests=False)
+    server = xmlrpc_server.SimpleXMLRPCServer((bind_addr, port), logRequests=False)
     server.register_instance(RemoteControl(project_name, run_callback))
     server.register_introspection_functions()
     print('\nMulti-Mechanize: %s listening on port %i' % (bind_addr, port))
