@@ -7,7 +7,7 @@
 #  This file is part of Multi-Mechanize | Performance Test Framework
 #
 from __future__ import print_function
-from six.moves import configparser as ConfigParser
+from six.moves import configparser
 import multiprocessing
 import optparse
 import os
@@ -20,18 +20,18 @@ from datetime import datetime
 
 try:
     # installed
-    import multimechanize
+    import oct.multimechanize
 except ImportError:
     # from dev/source
     this_dir = os.path.abspath(os.path.dirname(__file__))
     sys.path.append(os.path.join(this_dir, '../../'))
-    import multimechanize
+    import oct.multimechanize
 
 import oct.multimechanize.core as core
 import oct.multimechanize.results as results
 import oct.multimechanize.resultswriter as resultswriter
 import oct.multimechanize.progressbar as progressbar
-from oct.multimechanize import __version__ as VERSION
+from oct.multimechanize import __version__ as version
 
 
 def main():
@@ -40,7 +40,7 @@ def main():
     """
 
     usage = 'Usage: %prog <project name> [options]'
-    parser = optparse.OptionParser(usage=usage, version=VERSION)
+    parser = optparse.OptionParser(usage=usage, version=version)
     parser.add_option('-p', '--port', dest='port', type='int', help='rpc listener port')
     parser.add_option('-r', '--results', dest='results_dir', help='results directory to reprocess')
     parser.add_option('-b', '--bind-addr', dest='bind_addr', help='rpc bind address', default='localhost')
@@ -61,8 +61,8 @@ def main():
     if cmd_opts.results_dir:  # don't run a test, just re-process results
         rerun_results(project_name, cmd_opts, cmd_opts.results_dir)
     elif cmd_opts.port:
-        import multimechanize.rpcserver
-        multimechanize.rpcserver.launch_rpc_server(cmd_opts.bind_addr, cmd_opts.port, project_name, run_test)
+        import oct.multimechanize.rpcserver
+        oct.multimechanize.rpcserver.launch_rpc_server(cmd_opts.bind_addr, cmd_opts.port, project_name, run_test)
     else:
         run_test(project_name, cmd_opts)
     return
@@ -73,7 +73,9 @@ def run_test(project_name, cmd_opts, remote_starter=None):
         remote_starter.test_running = True
         remote_starter.output_dir = None
 
-    run_time, rampup, results_ts_interval, console_logging, progress_bar, results_database, post_run_script, xml_report, user_group_configs = configure(project_name, cmd_opts)
+    (run_time, rampup, results_ts_interval, console_logging,
+     progress_bar, results_database, post_run_script, xml_report,
+     user_group_configs) = configure(project_name, cmd_opts)
 
     run_localtime = time.localtime()
     milisec = datetime.now().microsecond
@@ -113,7 +115,10 @@ def run_test(project_name, cmd_opts, remote_starter=None):
             while elapsed < (run_time + 1):
                 p.update_time(elapsed)
                 if sys.platform.startswith('win'):
-                    print('{0}   transactions: {1}  timers: {2}  errors: {3}\r'.format(p, rw.trans_count, rw.timer_count, rw.error_count), end=' ')
+                    print('{0}   transactions: {1}  timers: {2}  errors: {3}\r'.format(p,
+                                                                                       rw.trans_count,
+                                                                                       rw.timer_count,
+                                                                                       rw.error_count), end=' ')
                 else:
                     print('%s   transactions: %i  timers: %i  errors: %i' % (p, rw.trans_count, rw.timer_count,
                                                                              rw.error_count))
@@ -152,10 +157,11 @@ def run_test(project_name, cmd_opts, remote_starter=None):
 
     if results_database is not None:
         print('loading results into database: %s\n' % results_database)
-        import multimechanize.resultsloader
-        multimechanize.resultsloader.load_results_database(project_name,
-                                                           run_localtime, output_dir, results_database,
-                                                           run_time, rampup, results_ts_interval, user_group_configs)
+        import oct.multimechanize.resultsloader
+        oct.multimechanize.resultsloader.load_results_database(project_name,
+                                                               run_localtime, output_dir, results_database,
+                                                               run_time, rampup,
+                                                               results_ts_interval, user_group_configs)
 
     if post_run_script is not None:
         print('running post_run_script: %s\n' % post_run_script)
@@ -173,7 +179,8 @@ def run_test(project_name, cmd_opts, remote_starter=None):
 def rerun_results(project_name, cmd_opts, results_dir):
     output_dir = '%s/%s/results/%s/' % (cmd_opts.projects_dir, project_name, results_dir)
     saved_config = '%s/config.cfg' % output_dir
-    run_time, rampup, results_ts_interval, console_logging, progress_bar, results_database, post_run_script, xml_report, user_group_configs = configure(project_name, cmd_opts, config_file=saved_config)
+    (run_time, rampup, results_ts_interval, console_logging, progress_bar, results_database,
+     post_run_script, xml_report, user_group_configs) = configure(project_name, cmd_opts, config_file=saved_config)
     print('\n\nanalyzing results...\n')
     results.output_results(output_dir, 'results.csv', run_time, rampup, results_ts_interval, user_group_configs,
                            xml_report)
@@ -184,8 +191,12 @@ def rerun_results(project_name, cmd_opts, results_dir):
 
 
 def configure(project_name, cmd_opts, config_file=None):
+    """
+
+    :rtype : object
+    """
     user_group_configs = []
-    config = ConfigParser.ConfigParser()
+    config = configparser.ConfigParser()
     if config_file is None:
         config_file = '%s/%s/config.cfg' % (cmd_opts.projects_dir, project_name)
     config.read(config_file)
@@ -196,27 +207,27 @@ def configure(project_name, cmd_opts, config_file=None):
             results_ts_interval = config.getint(section, 'results_ts_interval')
             try:
                 console_logging = config.getboolean(section, 'console_logging')
-            except ConfigParser.NoOptionError:
+            except configparser.NoOptionError:
                 console_logging = False
             try:
                 progress_bar = config.getboolean(section, 'progress_bar')
-            except ConfigParser.NoOptionError:
+            except configparser.NoOptionError:
                 progress_bar = True
             try:
                 results_database = config.get(section, 'results_database')
                 if results_database == 'None':
                     results_database = None
-            except ConfigParser.NoOptionError:
+            except configparser.NoOptionError:
                 results_database = None
             try:
                 post_run_script = config.get(section, 'post_run_script')
                 if post_run_script == 'None':
                     post_run_script = None
-            except ConfigParser.NoOptionError:
+            except configparser.NoOptionError:
                 post_run_script = None
             try:
                 xml_report = config.getboolean(section, 'xml_report')
-            except ConfigParser.NoOptionError:
+            except configparser.NoOptionError:
                 xml_report = False
         else:
             threads = config.getint(section, 'threads')
@@ -225,7 +236,8 @@ def configure(project_name, cmd_opts, config_file=None):
             ug_config = UserGroupConfig(threads, user_group_name, script)
             user_group_configs.append(ug_config)
 
-    return (run_time, rampup, results_ts_interval, console_logging, progress_bar, results_database, post_run_script, xml_report, user_group_configs)
+    return (run_time, rampup, results_ts_interval, console_logging,
+            progress_bar, results_database, post_run_script, xml_report, user_group_configs)
 
 
 class UserGroupConfig(object):
